# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.4.0a0

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/@retrolab/app@0.3.16...879e644e172dee4b37f5f3062877e61290e1fcdb))

### Enhancements made

- Update to JupyterLab 4.0 alpha [#319](https://github.com/jupyterlab/retrolab/pull/319) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Drop support for `retro_logo` [#324](https://github.com/jupyterlab/retrolab/pull/324) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2022-01-07&to=2022-01-21&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Adavidbrochart+updated%3A2022-01-07..2022-01-21&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2022-01-07..2022-01-21&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2022-01-07..2022-01-21&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.3.16

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.15...41a51ac002582baac9a89a2eb3426ac26e16a46f))

### Maintenance and upkeep improvements

- Update to the `@jupyterlab` 3.2.6 packages [#321](https://github.com/jupyterlab/retrolab/pull/321) ([@jtpio](https://github.com/jtpio))
- Remove allsettled polyfill [#318](https://github.com/jupyterlab/retrolab/pull/318) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2022-01-03&to=2022-01-07&type=c))

[@davidbrochart](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Adavidbrochart+updated%3A2022-01-03..2022-01-07&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2022-01-03..2022-01-07&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2022-01-03..2022-01-07&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3AmartinRenou+updated%3A2022-01-03..2022-01-07&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Awelcome+updated%3A2022-01-03..2022-01-07&type=Issues)

## 0.3.15

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.14...6815878b79fa1e43bff706bb42ff3a2ee5bc23bd))

### Enhancements made

- Enable auto scrolling for outputs by default [#288](https://github.com/jupyterlab/retrolab/pull/288) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Fix handling of the Python version in the release scripts [#315](https://github.com/jupyterlab/retrolab/pull/315) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-12-28&to=2022-01-03&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-12-28..2022-01-03&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-12-28..2022-01-03&type=Issues)

## 0.3.14

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.13...ec926de136ba17afd3335e8ad452b16bb173986b))

### Enhancements made

- Interface switcher menu [#309](https://github.com/jupyterlab/retrolab/pull/309) ([@jtpio](https://github.com/jtpio))
- Strip .ipynb extension for display in header and tab title [#296](https://github.com/jupyterlab/retrolab/pull/296) ([@jweill-aws](https://github.com/jweill-aws))
- Add extension for document-scoped search [#294](https://github.com/jupyterlab/retrolab/pull/294) ([@loichuder](https://github.com/loichuder))
- Improve menus [#289](https://github.com/jupyterlab/retrolab/pull/289) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Remove `playwright` dependency from the `app` folder [#307](https://github.com/jupyterlab/retrolab/pull/307) ([@jtpio](https://github.com/jtpio))
- Bump playwright version in package.json [#304](https://github.com/jupyterlab/retrolab/pull/304) ([@gabalafou](https://github.com/gabalafou))
- Switch to `maintainer-tools` action for Binder on PR [#301](https://github.com/jupyterlab/retrolab/pull/301) ([@jtpio](https://github.com/jtpio))
- Use `maintainer-tools` base setup action [#295](https://github.com/jupyterlab/retrolab/pull/295) ([@jtpio](https://github.com/jtpio))
- Remove unused build:test task in app [#293](https://github.com/jupyterlab/retrolab/pull/293) ([@loichuder](https://github.com/loichuder))
- Add UI test for the mobile layout [#292](https://github.com/jupyterlab/retrolab/pull/292) ([@jtpio](https://github.com/jtpio))
- Enforce labels on PRs [#291](https://github.com/jupyterlab/retrolab/pull/291) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- add alt text together during the 2021 diy a11y workshop (#1) [#310](https://github.com/jupyterlab/retrolab/pull/310) ([@tonyfast](https://github.com/tonyfast))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-11-12&to=2021-12-28&type=c))

[@gabalafou](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agabalafou+updated%3A2021-11-12..2021-12-28&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-11-12..2021-12-28&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-11-12..2021-12-28&type=Issues) | [@jweill-aws](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajweill-aws+updated%3A2021-11-12..2021-12-28&type=Issues) | [@loichuder](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Aloichuder+updated%3A2021-11-12..2021-12-28&type=Issues) | [@tonyfast](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Atonyfast+updated%3A2021-11-12..2021-12-28&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Awelcome+updated%3A2021-11-12..2021-12-28&type=Issues) | [@yuvipanda](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ayuvipanda+updated%3A2021-11-12..2021-12-28&type=Issues)

## 0.3.13

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.12...a77d66953de2d73931959a131837049322a59216))

### Enhancements made

- Ensure `@retrolab` settings [#265](https://github.com/jupyterlab/retrolab/pull/265) ([@jtpio](https://github.com/jtpio))

### Bugs fixed

- Fix handling of the MathJax URL to render Latex [#280](https://github.com/jupyterlab/retrolab/pull/280) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Fix plugin ids in the notebook extension [#284](https://github.com/jupyterlab/retrolab/pull/284) ([@jtpio](https://github.com/jtpio))
- Add UI test to check the retrolab settings are persisted [#281](https://github.com/jupyterlab/retrolab/pull/281) ([@jtpio](https://github.com/jtpio))
- Update UI Tests to use Galata [#273](https://github.com/jupyterlab/retrolab/pull/273) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Update testing docs [#278](https://github.com/jupyterlab/retrolab/pull/278) ([@jtpio](https://github.com/jtpio))
- Fix typos in readme [#271](https://github.com/jupyterlab/retrolab/pull/271) ([@jweill-aws](https://github.com/jweill-aws))
- edits to aid in navigation of Readme.md [#269](https://github.com/jupyterlab/retrolab/pull/269) ([@gutow](https://github.com/gutow))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-11-01&to=2021-11-12&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-11-01..2021-11-12&type=Issues) | [@gutow](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agutow+updated%3A2021-11-01..2021-11-12&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-11-01..2021-11-12&type=Issues) | [@jweill-aws](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajweill-aws+updated%3A2021-11-01..2021-11-12&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Akrassowski+updated%3A2021-11-01..2021-11-12&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Awelcome+updated%3A2021-11-01..2021-11-12&type=Issues)

## 0.3.12

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.11...8d92d7ff18a0b57d9aa1f64952064d3babc87de1))

### Bugs fixed

- Fix missing download command [#263](https://github.com/jupyterlab/retrolab/pull/263) ([@jtpio](https://github.com/jtpio))
- Fix handling of federated mime extensions [#262](https://github.com/jupyterlab/retrolab/pull/262) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Pass version spec as a GitHub Actions input [#254](https://github.com/jupyterlab/retrolab/pull/254) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Update the top screenshot in the README [#255](https://github.com/jupyterlab/retrolab/pull/255) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-10-14&to=2021-11-01&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-10-14..2021-11-01&type=Issues) | [@gutow](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agutow+updated%3A2021-10-14..2021-11-01&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-10-14..2021-11-01&type=Issues)

## 0.3.11

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.10...29c41d3b005701fcc2d7a0760addc65858b7231b))

### Bugs fixed

- Fix handling of kernelspec logo [#252](https://github.com/jupyterlab/retrolab/pull/252) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-10-14&to=2021-10-14&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-10-14..2021-10-14&type=Issues)

## 0.3.10

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.9...15a00e5691ef37e5d383ed982662d71c54d0bb6f))

### Maintenance and upkeep improvements

- Update to JupyterLab 3.2 [#240](https://github.com/jupyterlab/retrolab/pull/240) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-10-12&to=2021-10-14&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-10-12..2021-10-14&type=Issues)

## 0.3.9

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.8...a901cb1351735cbbd1163ba3c5ee553010f4d8ea))

### Bugs fixed

- Hoist the filebrowser factory plugin [#249](https://github.com/jupyterlab/retrolab/pull/249) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-10-11&to=2021-10-12&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-10-11..2021-10-12&type=Issues)

## 0.3.8

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.7...812e76db12dce15acc3ff582fd7cfb009fd33879))

### Enhancements made

- More document-oriented feel for the notebook (scrollbar) [#244](https://github.com/jupyterlab/retrolab/pull/244) ([@jtpio](https://github.com/jtpio))
- Improve tree page tab bar CSS [#243](https://github.com/jupyterlab/retrolab/pull/243) ([@jtpio](https://github.com/jtpio))
- Add missing translations to help extension [#237](https://github.com/jupyterlab/retrolab/pull/237) ([@krassowski](https://github.com/krassowski))

### Bugs fixed

- Fix handling of federated extensions [#245](https://github.com/jupyterlab/retrolab/pull/245) ([@jtpio](https://github.com/jtpio))
- Support disabling core retrolab extensions [#242](https://github.com/jupyterlab/retrolab/pull/242) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Update link to the stable Binder [#236](https://github.com/jupyterlab/retrolab/pull/236) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-09-23&to=2021-10-11&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-09-23..2021-10-11&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-09-23..2021-10-11&type=Issues) | [@krassowski](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Akrassowski+updated%3A2021-09-23..2021-10-11&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Awelcome+updated%3A2021-09-23..2021-10-11&type=Issues)

## 0.3.7

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.6...986ce55f74bd663512122f727a2f487d5df77eb2))

### Enhancements made

- Add support for translation [#229](https://github.com/jupyterlab/retrolab/pull/229) ([@jtpio](https://github.com/jtpio))
- Expose the file editor plugin to all pages [#227](https://github.com/jupyterlab/retrolab/pull/227) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Fix handling of `--skip-commit` [#232](https://github.com/jupyterlab/retrolab/pull/232) ([@jtpio](https://github.com/jtpio))
- Simplify bump version script [#224](https://github.com/jupyterlab/retrolab/pull/224) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Add a Binder section to the readme [#230](https://github.com/jupyterlab/retrolab/pull/230) ([@jtpio](https://github.com/jtpio))
- Update RELEASE.md to mention the Jupyter Releaser [#223](https://github.com/jupyterlab/retrolab/pull/223) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-09-10&to=2021-09-23&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-09-10..2021-09-23&type=Issues) | [@goanpeca](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agoanpeca+updated%3A2021-09-10..2021-09-23&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-09-10..2021-09-23&type=Issues)

## 0.3.6

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/v0.3.5...e1bd1bc708f3192c15bba4edbc424f3ffef54977))

### Bugs fixed

- Fix clean:static to not clean the console favicon [#221](https://github.com/jupyterlab/retrolab/pull/221) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Default clean script to clean the lab extension [#220](https://github.com/jupyterlab/retrolab/pull/220) ([@jtpio](https://github.com/jtpio))
- Build prod assets on release [#216](https://github.com/jupyterlab/retrolab/pull/216) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-09-08&to=2021-09-10&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-09-08..2021-09-10&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-09-08..2021-09-10&type=Issues)

## 0.3.5

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/0.3.4...ecdeb2816318af12ce5e6191ab59016414a88160))

### Enhancements made

- Show path in the console tab title [#208](https://github.com/jupyterlab/retrolab/pull/208) ([@jtpio](https://github.com/jtpio))

### Bugs fixed

- Fix handling of skip-commit [#212](https://github.com/jupyterlab/retrolab/pull/212) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Remove release-npm script [#210](https://github.com/jupyterlab/retrolab/pull/210) ([@jtpio](https://github.com/jtpio))
- Adopt the Jupyter Releaser [#207](https://github.com/jupyterlab/retrolab/pull/207) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-09-03&to=2021-09-08&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-09-03..2021-09-08&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-09-03..2021-09-08&type=Issues)

## 0.3.4

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/0.3.3...b9cba834c9f0cb150cbb4fff8f08007aa5bf08ca))

### Enhancements made

- Add an 'interface switcher' to the toolbar [#158](https://github.com/jupyterlab/retrolab/pull/158) ([@yuvipanda](https://github.com/yuvipanda))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-09-02&to=2021-09-03&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-09-02..2021-09-03&type=Issues) | [@yuvipanda](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ayuvipanda+updated%3A2021-09-02..2021-09-03&type=Issues)

## 0.3.3

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/0.3.2...ac9bac4f3ccfad16063aea1579fe0d64f79f4ae7))

### Enhancements made

- Add expose add in browser for galata [#203](https://github.com/jupyterlab/retrolab/pull/203) ([@fcollonval](https://github.com/fcollonval))
- Route on file browser navigation [#202](https://github.com/jupyterlab/retrolab/pull/202) ([@fcollonval](https://github.com/fcollonval))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-08-30&to=2021-09-02&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Afcollonval+updated%3A2021-08-30..2021-09-02&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-08-30..2021-09-02&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-08-30..2021-09-02&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Awelcome+updated%3A2021-08-30..2021-09-02&type=Issues)

## 0.3.2

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/0.3.1...ecd9b1ee96b01f418d098885c6e2442c60b8480b))

### New features added

- Add support for code consoles [#197](https://github.com/jupyterlab/retrolab/pull/197) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Update dependencies and resolutions [#199](https://github.com/jupyterlab/retrolab/pull/199) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-08-28&to=2021-08-30&type=c))

[@bollwyvl](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Abollwyvl+updated%3A2021-08-28..2021-08-30&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-08-28..2021-08-30&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-08-28..2021-08-30&type=Issues)

## 0.3.1

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/0.3.0...660066f7c58763bff9afcfcbaf005660f9889085))

### Enhancements made

- Fix support for RTC [#194](https://github.com/jupyterlab/retrolab/pull/194) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Update spec in the check release workflow [#193](https://github.com/jupyterlab/retrolab/pull/193) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-08-27&to=2021-08-28&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-08-27..2021-08-28&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-08-27..2021-08-28&type=Issues)

## 0.3.0

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/0.2.2...2f06d80c12f720d2c457b0db5a57390f004819f4))

### Enhancements made

- Provide `IStateDB` [#187](https://github.com/jupyterlab/retrolab/pull/187) ([@jtpio](https://github.com/jtpio))
- `jupyter retro --version` returns the version [#177](https://github.com/jupyterlab/retrolab/pull/177) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Update to JupyterLab 3.1 final [#189](https://github.com/jupyterlab/retrolab/pull/189) ([@jtpio](https://github.com/jtpio))
- Update to JupyterLab 3.1.0rc2 [#186](https://github.com/jupyterlab/retrolab/pull/186) ([@jtpio](https://github.com/jtpio))
- Improve the bump version script [#185](https://github.com/jupyterlab/retrolab/pull/185) ([@jtpio](https://github.com/jtpio))
- Update to jupyter-packaging 0.10 [#179](https://github.com/jupyterlab/retrolab/pull/179) ([@jtpio](https://github.com/jtpio))
- Reuse mobile view CSS from upstream JupyterLab [#178](https://github.com/jupyterlab/retrolab/pull/178) ([@jtpio](https://github.com/jtpio))
- Update to JupyterLab 3.1.0rc1 [#176](https://github.com/jupyterlab/retrolab/pull/176) ([@jtpio](https://github.com/jtpio))
- Add check-release CI workflow and Changelog [#173](https://github.com/jupyterlab/retrolab/pull/173) ([@jtpio](https://github.com/jtpio))
- Update to JupyterLab 3.1.0-beta.0 packages [#167](https://github.com/jupyterlab/retrolab/pull/167) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Add changelog for v0.3.0rc0 [#180](https://github.com/jupyterlab/retrolab/pull/180) ([@jtpio](https://github.com/jtpio))
- Add Changelog for 0.3.0b0 [#174](https://github.com/jupyterlab/retrolab/pull/174) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

- Check the application status before closing the tab [#166](https://github.com/jupyterlab/retrolab/pull/166) ([@jtpio](https://github.com/jtpio))
- Mimic classic notebook behavior for /tree/<path> [#159](https://github.com/jupyterlab/retrolab/pull/159) ([@yuvipanda](https://github.com/yuvipanda))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-05-31&to=2021-08-27&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Afcollonval+updated%3A2021-05-31..2021-08-27&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-05-31..2021-08-27&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-05-31..2021-08-27&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Awelcome+updated%3A2021-05-31..2021-08-27&type=Issues) | [@yuvipanda](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ayuvipanda+updated%3A2021-05-31..2021-08-27&type=Issues)

## 0.3.0rc1

([Full Changelog](https://github.com/jupyterlab/retrolab/compare/0.3.0rc0...9eaa171504b94869b850a46b97f748394d2154fa))

### Enhancements made

- Provide `IStateDB` [#187](https://github.com/jupyterlab/retrolab/pull/187) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Update to JupyterLab 3.1.0rc2 [#186](https://github.com/jupyterlab/retrolab/pull/186) ([@jtpio](https://github.com/jtpio))
- Improve the bump version script [#185](https://github.com/jupyterlab/retrolab/pull/185) ([@jtpio](https://github.com/jtpio))
- Add check-release CI workflow and Changelog [#173](https://github.com/jupyterlab/retrolab/pull/173) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-07-14&to=2021-07-22&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-07-14..2021-07-22&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-07-14..2021-07-22&type=Issues)

## v0.3.0rc0

([full changelog](https://github.com/jupyterlab/retrolab/compare/0.3.0b0...96671df35822f09721fd2e5df7118ce4fa2225ea))

### Enhancements made

- `jupyter retro --version` returns the version [#177](https://github.com/jupyterlab/retrolab/pull/177) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Update to jupyter-packaging 0.10 [#179](https://github.com/jupyterlab/retrolab/pull/179) ([@jtpio](https://github.com/jtpio))
- Reuse mobile view CSS from upstream JupyterLab [#178](https://github.com/jupyterlab/retrolab/pull/178) ([@jtpio](https://github.com/jtpio))
- Update to JupyterLab 3.1.0rc1 [#176](https://github.com/jupyterlab/retrolab/pull/176) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-07-06&to=2021-07-14&type=c))

[@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-07-06..2021-07-14&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-07-06..2021-07-14&type=Issues)

## v0.3.0b0

([full changelog](https://github.com/jupyterlab/retrolab/compare/0.3.0a2...574da61aa7c8cc4aa6840b0e548860f7ceeb11dc))

### Maintenance and upkeep improvements

- Update to JupyterLab 3.1.0-beta.0 packages [#167](https://github.com/jupyterlab/retrolab/pull/167) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

- Check the application status before closing the tab [#166](https://github.com/jupyterlab/retrolab/pull/166) ([@jtpio](https://github.com/jtpio))
- Backport PR #159 on branch 0.2.x (Mimic classic notebook behavior for /tree/<path>) [#161](https://github.com/jupyterlab/retrolab/pull/161) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Mimic classic notebook behavior for /tree/<path> [#159](https://github.com/jupyterlab/retrolab/pull/159) ([@yuvipanda](https://github.com/yuvipanda))
- [0.2.x] Backport #148 (Enable hub-extension) [#151](https://github.com/jupyterlab/retrolab/pull/151) ([@jtpio](https://github.com/jtpio))
- Backport PR #138 on branch 0.2.x (Easier to access RetroLab tree) [#150](https://github.com/jupyterlab/retrolab/pull/150) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Enable hub-extension [#148](https://github.com/jupyterlab/retrolab/pull/148) ([@jabbera](https://github.com/jabbera))
- Backport PR #144 on branch 0.2.x (Trigger CI on all branches for `push` events) [#145](https://github.com/jupyterlab/retrolab/pull/145) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Trigger CI on all branches for `push` events [#144](https://github.com/jupyterlab/retrolab/pull/144) ([@jtpio](https://github.com/jtpio))
- Backport PR #137 on branch 0.2.x (Follow-up to the move to the `jupyterlab` organization) [#142](https://github.com/jupyterlab/retrolab/pull/142) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Backport PR #140 on branch 0.2.x (Fix release workflow) [#141](https://github.com/jupyterlab/retrolab/pull/141) ([@meeseeksmachine](https://github.com/meeseeksmachine))
- Fix release workflow [#140](https://github.com/jupyterlab/retrolab/pull/140) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/retrolab/graphs/contributors?from=2021-05-28&to=2021-07-06&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Afcollonval+updated%3A2021-05-28..2021-07-06&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Agithub-actions+updated%3A2021-05-28..2021-07-06&type=Issues) | [@jabbera](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajabbera+updated%3A2021-05-28..2021-07-06&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ajtpio+updated%3A2021-05-28..2021-07-06&type=Issues) | [@meeseeksmachine](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ameeseeksmachine+updated%3A2021-05-28..2021-07-06&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Awelcome+updated%3A2021-05-28..2021-07-06&type=Issues) | [@yuvipanda](https://github.com/search?q=repo%3Ajupyterlab%2Fretrolab+involves%3Ayuvipanda+updated%3A2021-05-28..2021-07-06&type=Issues)
